% This file explains how to use the proposed feature extractor

% This Matlab file creates Matlab executables from the C codes. You need to
% call this file only once. Instead of using the generated kmeansClustering
% executable, you may also directly call the kmeans function provided by
% Matlab (this is most probably more optimized than kmeansClustering)
createMexExecutables


% First set the parameter values
minCircleRadius = 4;                % Size of the smallest circular object
                                    % (tissue component) to be located
winSize = 29;                       % Size of a salient subregion
K = 1500;                           % Number of clusters
weightMatFilename = 'RBMweights';   % File storing the weights of RBMs



% This function learns the deep belief network (DBN) of RBMs whose last
% layer will be used in feature extraction. It learns this DBN from
% randomly selected salient subregions of randomly selected training
% images. For that, after randomly selecting your images, you need to put
% their names in the selectedTrainingImageFilenames variable. Please do not
% forget to select the training images from different classes. This
% learnDBN function works for four-layer DBNs with the specified hidden
% unit numbers. If you want to change its architecture, please read the
% comments at the beginning of the learnDBN function as well as those in
% the learnClusteringVectors and extractImageFeatures functions.
selectedTrainingImageFilenames{1} = 't1.jpg';
selectedTrainingImageFilenames{2} = 't2.jpg';
selectedTrainingImageFilenames{3} = 't3.jpg';
% ...
learnDBN(selectedTrainingImageFilenames, weightMatFilename, minCircleRadius, winSize);


% This function learns the clustering vectors fron randomly selected
% salient subregions of randomly selected training images. 
V = learnClusteringVectors(selectedTrainingImageFilenames, weightMatFilename, minCircleRadius, winSize, K);


% After learning the weights and the clustering vectors, now you are ready
% to extract the deep features of a given image using the following
% extractImageFeatures function
deepFeatures = extractImageFeatures('t1.jpg', weightMatFilename, V, minCircleRadius, winSize, K);


% In order to use these features for classification, extract the deep
% features of the images in your training set, use a classifier (we use an
% SVM classifier in our study), and then use this classifier to label the
% unannotated images.
% for i = 1 : trNo
%     deepFeatures(i, :) = extractImageFeatures(trainingImageFilenames{i}, weightMatFilename, V, minCircleRadius, winSize, K);
% end
% model = train your classifier
% label your image with the trained model
    



